@@ -59,6 +59,7 @@ class Subscription(models.Model):
 
     # Aditional parameters for deep link
     quiz = models.TextField(null=True, blank=True)
+    client_ip = models.GenericIPAddressField(null=True, blank=True)
 
     def get_token(self):
         """
@@ -75,7 +76,7 @@ class Subscription(models.Model):
         unique_together = [('user', 'plan')]
 
     @classmethod
-    def create_from_token(cls, token, plan, user, quiz=None):
+    def create_from_token(cls, token, plan, user, quiz=None, client_ip=None):
         """
         Creates new subscription from given token with plan for given user.
         :param token: Paymnet source (starts with pm_)
@@ -83,6 +84,7 @@ class Subscription(models.Model):
         :param plan: Selected plan (Plan object)
         :param user: Subscriber
         :param quiz: URL encoded quiz data (user selected options for depp link)
+        :param client_ip: Remote user IP address
         """
 
         try:
@@ -130,8 +132,9 @@ class Subscription(models.Model):
             sub = stripe.Subscription.create(**kwargs)
             obj.subscription_id = sub.id
 
-            if quiz:
-                obj.quiz = quiz
+            # Update metadata fields
+            obj.quiz = quiz
+            obj.client_ip = client_ip
 
             obj.save()
 
@@ -149,10 +152,13 @@ class Subscription(models.Model):
 
         link = plan.deep_link
 
-        for p in [self.quiz, 'subscription_id=%s' % self.subscription_id]:
-            if not p:
-                continue
+        params = list(filter(bool, [
+            'subscription_id=%s' % self.subscription_id,
+            ('client_ip=%s' % self.client_ip) if self.client_ip else None,
+            ('email=%s' % self.user.email) if self.user.email else None
+        ]))
 
+        for p in params:
             glue = '&' if '?' in link else '?'
             link = glue.join([link, p])
 
